@@ -5,29 +5,83 @@
 # URL: https://github.com/xolox/python-vcs-repo-mgr
 
 """
-Usage: vcs-tool [OPTIONS]
+Usage: vcs-tool [OPTIONS] [ARGS]
+
+Command line program to perform common operations (in the context of
+packaging/deployment) on version control repositories. Supports Bazaar,
+Mercurial and Git repositories.
 
 Supported options:
 
-  -r, --repository=NAME       name of configured repository
-      --rev, --revision=REV   revision to export (used in combination
-                              with the options -n, -i and -e)
-  -d, --find-directory        print the absolute path of the local repository
-  -n, --find-revision-number  find the local revision number of the revision
-                              given with --rev
-  -i, --find-revision-id      find the global revision id of the revision
-                              given with --rev
-  -u, --update                update local clone of repository by
-                              pulling latest changes from remote
-                              repository
-  -e, --export=DIR            export contents of repository to
-                              directory (used in combination
-                              with --revision)
-  -v, --verbose               make more noise
-  -h, --help                  show this message and exit
+  -r, --repository=REPOSITORY_NAME
 
-The value of --revision defaults to `last:1' for Bazaar repositories,
-`master' for git repositories and `default' for Mercurial repositories.
+    Select a repository to operate on by providing the name of a repository
+    defined in one of the configuration files ~/.vcs-repo-mgr.ini and
+    /etc/vcs-repo-mgr.ini.
+
+  --rev, --revision=REVISION
+
+    Select a revision to operate on. Accepts any string that's supported by the
+    VCS system that manages the repository, which means you can provide branch
+    names, tag names, exact revision ids, etc. This option is used in
+    combination with the --find-revision-number, --find-revision-id and
+    --export options.
+
+    If this option is not provided a default revision is selected: `last:1' for
+    Bazaar repositories, `master' for git repositories and `default' (not
+    `tip'!) for Mercurial repositories.
+
+  -n, --find-revision-number
+
+    Print the local revision number (an integer) of the revision given with the
+    --revision option. Revision numbers are useful as a build number or when a
+    simple, incrementing version number is required. Revision numbers should
+    not be used to unambiguously refer to a revision (use revision ids for that
+    instead). This option is used in combination with the --repository and
+    --revision options.
+
+  -i, --find-revision-id
+
+    Print the global revision id (a string) of the revision given with the
+    --revision option. Global revision ids are useful to unambiguously refer to
+    a revision. This option is used in combination with the --repository and
+    --revision options.
+
+  -s, --sum-revisions
+
+    Print the summed revision numbers of multiple repository/revision pairs.
+    The repository/revision pairs are taken from the positional arguments to
+    vcs-repo-mgr.
+
+    This is useful when you're building a package based on revisions from
+    multiple VCS repositories. By taking changes in all repositories into
+    account when generating version numbers you can make sure that your version
+    number is bumped with every single change.
+
+  -u, --update
+
+    Create/update the local clone of a remote repository by pulling the latest
+    changes from the remote repository. This option is used in combination with
+    the --repository option.
+
+  -e, --export=DIRECTORY
+
+    Export the contents of a specific revision of a repository to a local
+    directory. This option is used in combination with the --repository and
+    --revision options.
+
+  -d, --find-directory
+
+    Print the absolute pathname of a local repository. This option is used in
+    combination with the --repository option.
+
+  -v, --verbose
+
+    Make more noise.
+
+  -h, --help
+
+    Show this message and exit.
 """
 
 # Standard library modules.
@@ -42,11 +96,7 @@ import coloredlogs
 from executor import execute
 
 # Modules included in our package.
-from vcs_repo_mgr import find_configured_repository
-
-# Known configuration file locations.
-USER_CONFIG_FILE = os.path.expanduser('~/.vcs-repo-mgr.ini')
-SYSTEM_CONFIG_FILE = '/etc/vcs-repo-mgr.ini'
+from vcs_repo_mgr import find_configured_repository, sum_revision_numbers
 
 # Initialize a logger.
 logger = logging.getLogger(__name__)
@@ -66,10 +116,10 @@ def main():
     actions = []
     # Parse the command line arguments.
     try:
-        options, arguments = getopt.gnu_getopt(sys.argv[1:], 'r:dniue:vh', [
+        options, arguments = getopt.gnu_getopt(sys.argv[1:], 'r:dnisue:vh', [
             'repository=', 'rev=', 'revision=', 'find-directory',
-            'find-revision-number', 'find-revision-id', 'update', 'export=',
-            'verbose', 'help'
+            'find-revision-number', 'find-revision-id', 'sum-revisions',
+            'update', 'export=', 'verbose', 'help'
         ])
         for option, value in options:
             if option in ('-r', '--repository'):
@@ -88,6 +138,10 @@ def main():
             elif option in ('-i', '--find-revision-id'):
                 assert repository, "Please specify a repository first!"
                 actions.append(functools.partial(print_revision_id, repository, revision))
+            elif option in ('-s', '--sum-revisions'):
+                assert len(arguments) >= 2, "Please specify one or more repository/revision pairs!"
+                actions.append(functools.partial(print_summed_revisions, arguments))
+                arguments = []
             elif option in ('-u', '--update'):
                 assert repository, "Please specify a repository first!"
                 actions.append(functools.partial(repository.update))
@@ -106,7 +160,7 @@ def main():
             return
     except Exception as e:
         logger.error(e)
-        print()
+        print('')
         usage()
         sys.exit(1)
     # Execute the requested action(s).
@@ -122,10 +176,13 @@ def print_directory(repository):
 
 def print_revision_number(repository, revision):
     print(repository.find_revision_number(revision))
-    
+
 def print_revision_id(repository, revision):
     print(repository.find_revision_id(revision))
 
+def print_summed_revisions(arguments):
+    print(sum_revision_numbers(arguments))
+
 def usage():
     print(__doc__.strip())
 
